@@ -90,17 +90,8 @@ def main(feature_folder, create_learning_curve=False):
     # Output data for documentation
     print("Classes (nr of symbols): %i" % len(formula_id2index))
 
-    print("#### Preprocessing")
-    print("```")
-    for algorithm in preprocessing_queue:
-        print("* " + str(algorithm))
-    print("```")
-
-    print("#### Features (%i)" % input_features)
-    print("```")
-    for algorithm in feature_list:
-        print("* %s" % str(algorithm))
-    print("```")
+    preprocessing.print_preprocessing_list(preprocessing_queue)
+    features.print_featurelist(feature_description['features'])
 
     logging.info("Start creating pfiles")
 
