@@ -59,6 +59,18 @@ def get_preprocessing_queue(preprocessing_list):
                                 config_key='preprocessing',
                                 module=sys.modules[__name__])
 
+
+def print_preprocessing_list(preproc_list):
+    """Print the preproc_list in a human-readable form.
+    :type preproc_list: List of strings
+    """
+    preprocessing_queue = get_preprocessing_queue(preproc_list)
+    print("## Preprocessing")
+    print("```")
+    for algorithm in preprocessing_queue:
+        print("* " + str(algorithm))
+    print("```")
+
 # Only preprocessing classes follow
 # Everyone must have a __str__, __repr__ and __call__
 # where
